==> 0.0.49.tar.gz: example/lib/Screen/DashBoardScreen.dart <==
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/ImageAssets.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:bui_component/DashBoardComponent.dart';
import '../Utils/class_builder.dart';
import 'LeadScreen.dart';
import 'HomeScreen.dart';
import 'ContactScreen.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:example/Firebase Classes/sign_in.dart';

class DashBoardScreen extends StatefulWidget {
  @override
  DashBoardScreenState createState() => DashBoardScreenState();
}

class DashBoardScreenState extends State<DashBoardScreen>
    with TickerProviderStateMixin {
  KFDrawerController _drawerController;

  List<Color> colors = [AppColors.APP_COLOR_PRIMARY, AppColors.APP_COLOR_WHITE];

  @override
  void initState() {
    ClassBuilder.registerClasses();
    super.initState();
    getStringValuesSF();
    _drawerController = KFDrawerController(
      initialPage: ClassBuilder.fromString('HomeScreen'),
      items: [
        KFDrawerItem.initWithPage(
          text: Text(
            'Account',
            style: TextStyle(color: Colors.white),
          ),
          icon: Icon(Icons.account_box, color: Colors.white),
          page: HomeScreen(onMenuIconPressed: onMenuIconPressed),
        ),
        KFDrawerItem.initWithPage(
          text: Text('Leads', style: TextStyle(color: Colors.white)),
          icon: Icon(Icons.leaderboard, color: Colors.white),
          page: LeadScreen(onMenuIconPressed: onMenuIconPressed),
        ),
        KFDrawerItem.initWithPage(
          text: Text(
            'Contacts',
            style: TextStyle(color: Colors.white),
          ),
          icon: Icon(Icons.contacts, color: Colors.white),
          page: ContactScreen(onMenuIconPressed: onMenuIconPressed),
        ),
        /*KFDrawerItem.initWithPage(
          text: Text(
            'Theme',
            style: TextStyle(color: Colors.white),
          ),
          icon: Icon(Icons.color_lens_sharp, color: Colors.white),
          page: ThemePickerSelect(onMenuIconPressed: onMenuIconPressed),
        ),*/
      ],
    );
  }

  Future<void> onMenuIconPressed() async {
    getStringValuesSF();
    this.mounted;
  }

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString('stringValue');

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);
      setState(() {
        colors = [Color(colorCodeInt), AppColors.APP_COLOR_WHITE];
        //  DashBoardComponent(drawerController: _drawerController,signOutFunction:signOutFunction,color:colors);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
        onWillPop: () {
          getStringValuesSF();
          _drawerController.close();
          /*    Navigator.pushAndRemoveUntil(
              context,
              PageRouteBuilder(pageBuilder: (BuildContext context, Animation animation,
                  Animation secondaryAnimation) {
                return SignUpScreen();
              }, transitionsBuilder: (BuildContext context, Animation<double> animation,
                  Animation<double> secondaryAnimation, Widget child) {
                return new SlideTransition(
                  position: new Tween<Offset>(
                    begin: const Offset(1.0, 0.0),
                    end: Offset.zero,
                  ).animate(animation),
                  child: child,
                );
              }),
                  (Route route) => false);*/
          return;
        },
        child: DashBoardComponent(
          drawerController: _drawerController,
          signOutFunction: signOutFunction,
          versionName: "1.0.0",
          color: colors,
          logo: Image.asset(
            ImageAssets.LOGO_WITH_NAME,
            height: MediaQuery.of(context).size.height * 0.2,
          ),
        ));
  }

  Future<void> signOutFunction() async {
    await FirebaseAuth.instance.signOut();
    await signOutGoogle(context);

    DashBoardComponentState.color = [
      AppColors.APP_COLOR_PRIMARY,
      AppColors.APP_COLOR_WHITE
    ];
  }
}

==> 0.0.50.tar.gz: example/lib/Screen/DashBoardScreen.dart <==
import 'package:example/Constants/AppStrings.dart';
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/ImageAssets.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:bui_component/DashBoardComponent.dart';
import '../Utils/class_builder.dart';
import 'LeadScreen.dart';
import 'HomeScreen.dart';
import 'ContactScreen.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:example/Firebase Classes/sign_in.dart';

class DashBoardScreen extends StatefulWidget {
  @override
  DashBoardScreenState createState() => DashBoardScreenState();
}

class DashBoardScreenState extends State<DashBoardScreen>
    with TickerProviderStateMixin {
  KFDrawerController _drawerController;

  List<Color> colors = [AppColors.APP_COLOR_PRIMARY, AppColors.APP_COLOR_WHITE];

  @override
  void initState() {
    ClassBuilder.registerClasses();
    super.initState();
    getStringValuesSF();
    _drawerController = KFDrawerController(
      initialPage: ClassBuilder.fromString('HomeScreen'),
      items: [
        KFDrawerItem.initWithPage(
          text: Text(
            'Account',
            style: TextStyle(color: Colors.white),
          ),
          icon: Icon(Icons.account_box, color: Colors.white),
          page: HomeScreen(onMenuIconPressed: onMenuIconPressed),
        ),
        KFDrawerItem.initWithPage(
          text: Text('Leads', style: TextStyle(color: Colors.white)),
          icon: Icon(Icons.leaderboard, color: Colors.white),
          page: LeadScreen(onMenuIconPressed: onMenuIconPressed),
        ),
        KFDrawerItem.initWithPage(
          text: Text(
            'Contacts',
            style: TextStyle(color: Colors.white),
          ),
          icon: Icon(Icons.contacts, color: Colors.white),
          page: ContactScreen(onMenuIconPressed: onMenuIconPressed),
        ),
        KFDrawerItem.initWithPage(
          text: Text(
            'Task',
            style: TextStyle(color: Colors.white),
          ),
          icon: Icon(Icons.table_view, color: Colors.white),
          page: ContactScreen(onMenuIconPressed: onMenuIconPressed),
        ),
        /*KFDrawerItem.initWithPage(
          text: Text(
            'Theme',
            style: TextStyle(color: Colors.white),
          ),
          icon: Icon(Icons.color_lens_sharp, color: Colors.white),
          page: ThemePickerSelect(onMenuIconPressed: onMenuIconPressed),
        ),*/
      ],
    );
  }

  Future<void> onMenuIconPressed() async {
    getStringValuesSF();
    this.mounted;
  }

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);
      setState(() {
        colors = [Color(colorCodeInt), AppColors.APP_COLOR_WHITE];
        //  DashBoardComponent(drawerController: _drawerController,signOutFunction:signOutFunction,color:colors);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
        onWillPop: () {
          getStringValuesSF();
          _drawerController.close();
          /*    Navigator.pushAndRemoveUntil(
              context,
              PageRouteBuilder(pageBuilder: (BuildContext context, Animation animation,
                  Animation secondaryAnimation) {
                return SignUpScreen();
              }, transitionsBuilder: (BuildContext context, Animation<double> animation,
                  Animation<double> secondaryAnimation, Widget child) {
                return new SlideTransition(
                  position: new Tween<Offset>(
                    begin: const Offset(1.0, 0.0),
                    end: Offset.zero,
                  ).animate(animation),
                  child: child,
                );
              }),
                  (Route route) => false);*/
          return;
        },
        child: DashBoardComponent(
          drawerController: _drawerController,
          signOutFunction: signOutFunction,
          versionName: "1.0.0",
          color: colors,
          logo: Image.asset(
            ImageAssets.LOGO_WITH_NAME,
            height: MediaQuery.of(context).size.height * 0.2,
          ),
        ));
  }

  Future<void> signOutFunction() async {
    await FirebaseAuth.instance.signOut();
    await signOutGoogle(context);

    DashBoardComponentState.color = [
      AppColors.APP_COLOR_PRIMARY,
      AppColors.APP_COLOR_WHITE
    ];
  }
}
